import click
import os

from meerkat import email as send_email, ping as send_ping, sms as send_sms, slack as send_slack
from meerkat.api import get_user_token, register_user

@click.group()
def meerkat():
    pass

@meerkat.command()
def ping():
    """Trigger ping sound to play from your local machine"""
    send_ping()

@meerkat.command()
@click.argument('message', type=str)
def email(message):
    """Send an email to your MeerkatIO email address with MESSAGE content"""
    send_email(message=message)

@meerkat.command()
@click.argument('message', type=str)
def sms(message):
    """Send an SMS to your MeerkatIO email address with MESSAGE content"""
    send_sms(message=message)

@meerkat.command()
@click.argument('message', type=str)
def slack(message):
    """Send a Slack direct message to your MeerkatIO email address with MESSAGE content"""
    send_slack(message=message)

@meerkat.command()
def login():
    """Login to MeerkatIO Platform and setup local environment"""
    email = click.prompt("Enter Email")
    password = click.prompt("Enter Password", hide_input=True)
    token = get_user_token(email, password)

    if not token:
        click.echo("Invalid email or password.")
        return

    #save token to user HOME and set OS env
    with open(os.path.expanduser("~") + "/.meerkat", "w") as file:
        file.write(token)
    os.environ["MEERKAT_TOKEN"] = token

    click.echo(f"\nMeerkatIO initialized successfully!")

@meerkat.command()
def register():
    """Register on the MeerkatIO Platform and setup local environment"""
    email = click.prompt("Enter Email")
    password = click.prompt("Enter Password", hide_input=True)
    token = register_user(email, password)

    if not token:
        click.echo("Registration error, please check email and password.")
        return

    #save token to user HOME and set OS env
    with open(os.path.expanduser("~") + "/.meerkat", "w") as file:
        file.write(token)
    os.environ["MEERKAT_TOKEN"] = token

    click.echo(f"\nMeerkatIO account created successfully! Your 30 day free trial starts now. Go to https://meerkatio.com/account to configure additional communication channels.")

if __name__ == "__main__":
    meerkat()


import os
import time
import importlib.resources as resources
from IPython.core.magic import Magics, magics_class, line_magic
from IPython import get_ipython

from os import environ
environ['PYGAME_HIDE_SUPPORT_PROMPT'] = '1'
from pygame import mixer

from meerkat.api import send_meerkat_notification

module_runtime = int(time.time()*1000)

if not os.environ.get("MEERKAT_TOKEN"):
    try:
        with open(os.path.expanduser("~") + "/.meerkat") as file:
            os.environ["MEERKAT_TOKEN"] = file.read()
    except Exception as e:
        pass

def _play_sound(file_name: str):
    mixer.init()
    mixer.music.load(file_name)
    mixer.music.play()
    time.sleep(2)

#
# Notification Functions
#
def ping():
    sound_path = resources.files("meerkat") / "ping_sounds/default_ping.mp3"
    _play_sound(str(sound_path))

def email(message="", token=None):
    if token == None:
        token = os.environ.get("MEERKAT_TOKEN")

    if not token:
        print("No MeerkatIO token found in the environment. Please login using `meerkat login` or go to https://meerkatio.com to set up your account to enable this feature.")
        return
    
    return send_meerkat_notification("email", token, message)

def sms(message="", token=None):
    if token == None:
        token = os.environ.get("MEERKAT_TOKEN")

    if not token:
        print("No MeerkatIO token found in the environment. Please login using `meerkat login` or go to https://meerkatio.com to set up your account to enable this feature.")
        return
    
    return send_meerkat_notification("sms", token, message)

def slack(message="", token=None):
    if token == None:
        token = os.environ.get("MEERKAT_TOKEN")

    if not token:
        print("No MeerkatIO token found in the environment. Please login using `meerkat login` or go to https://meerkatio.com to set up your account to enable this feature.")
        return
    
    return send_meerkat_notification("slack", token, message)

#
# iPython Extension
#

@magics_class
class MeerkatMagics(Magics):
    @line_magic
    def ping(self, line):
        sound_path = resources.files("meerkat") / "ping_sounds/default_ping.mp3"
        _play_sound(str(sound_path))

    @line_magic
    def email(self, line):
        email(line)

    @line_magic
    def sms(self, line):
        sms(line)

    @line_magic
    def slack(self, line):
        slack(line)

try:
    # Register the magics with the notebook
    ip = get_ipython()
    ip.register_magics(MeerkatMagics)
except:
    # not in a notebook
    pass


from setuptools import setup, find_packages

setup(
    name='meerkatio',
    version='1.17',
    packages=find_packages(),
    package_data={'meerkat': ['ping_sounds/*.mp3']},
    include_package_data=True,
    install_requires=[
        "requests",
        "click",
        "typing_extensions==4.11.0",
        "ipython",
        "pygame"
    ],
    entry_points='''
        [console_scripts]
        meerkat=meerkat.cli:meerkat
    ''',
    author="MeerkatIO",
    description="Personal notification and debug tool for multi-tasking software developers",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    license=open("LICENSE").read(),
    keywords=["notification", "alerting", "personal", "productivity", "big data"],
    url="https://meerkatio.com"
)
